==> easchersim-0.4.post6.tar.gz: easchersim-0.4.post6/src/easchersim/__init__.py <==
# The Clear BSD License
#
# Copyright (c) 2021 Austin Cummings
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted (subject to the limitations in the disclaimer
# below) provided that the following conditions are met:
#
#      * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#
#      * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#      * Neither the name of the copyright holder nor the names of its
#      contributors may be used to endorse or promote products derived from this
#      software without specific prior written permission.
#
# NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY
# THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

r"""EASCherSim - Simulate optical Cherenkov emission of Extensive Air Showers.
Python package and library.

***********
Application
***********

Application

.. autosummary::
   :toctree:

   EASCherSim.eas_cher_sim


******************
Simulation Modules
******************

Scientific modules

.. autosummary::
   :toctree:
   :nosignatures:

   EASCherSim.atmosphere
   EASCherSim.cher_func
   EASCherSim.electron_func
   EASCherSim.spatial_cherenkov_profile

*****************
Utility Functions
*****************

Supporting classes and functions for constants, IO operation, plotting etc.

.. autosummary::
   :toctree:
   :nosignatures:

   EASCherSim.constants
   EASCherSim.fit_func
   EASCherSim.geometry
   EASCherSim.io_func
   EASCherSim.plot

"""

__all__ = [
    "atmosphere",
    "cher_func",
    "constants",
    "electron_func",
    "fit_func",
    "geometry",
    "io_func",
    "spatial_cherenkov_profile",
    "plot"
]

from . import atmosphere, cher_func, constants, electron_func, fit_func, geometry, io_func, spatial_cherenkov_profile, plot

==> easchersim-1.1.tar.gz: easchersim-1.1/src/easchersim/__init__.py <==
# The Clear BSD License
#
# Copyright (c) 2021 Austin Cummings
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted (subject to the limitations in the disclaimer
# below) provided that the following conditions are met:
#
#      * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#
#      * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#      * Neither the name of the copyright holder nor the names of its
#      contributors may be used to endorse or promote products derived from this
#      software without specific prior written permission.
#
# NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY
# THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

r"""EASCherSim - Simulate optical Cherenkov emission of Extensive Air Showers.
Python package and library.

***********
Application
***********

Application

.. autosummary::
   :toctree:

   easchersim.eas_cher_sim


******************
Simulation Modules
******************

Scientific modules

.. autosummary::
   :toctree:
   :nosignatures:

   easchersim.atmosphere
   easchersim.cher_func
   easchersim.electron_func
   easchersim.spatial_cherenkov_profile

*****************
Utility Functions
*****************

Supporting classes and functions for constants, IO operation, plotting etc.

.. autosummary::
   :toctree:
   :nosignatures:

   easchersim.constants
   easchersim.fit_func
   easchersim.geometry
   easchersim.io_func
   easchersim.plot

"""

__all__ = [
    "atmosphere",
    "cher_func",
    "constants",
    "electron_func",
    "fit_func",
    "geometry",
    "io_func",
    "spatial_cherenkov_profile",
    "plot"
]

from . import atmosphere, cher_func, constants, electron_func, fit_func, geometry, io_func, spatial_cherenkov_profile, plot
